@@ -63,7 +63,8 @@ void FacebookAccount::setAvatar(const QUrl &url)
 
     m_avatarUrl = url.toString();
     QNetworkRequest request(url);
-    QNetworkReply *reply = FaceBrick::networkManager()->get(request);
+    request.setAttribute(QNetworkRequest::HttpPipeliningAllowedAttribute, true);
+    QNetworkReply *reply = FaceBrick::instance()->networkManager()->get(request);
     connect(reply, SIGNAL(finished()), SLOT(onAvatarDownloaded()));
 
     // modified() is emitted when avatar download is done.
@@ -74,7 +75,6 @@ void FacebookAccount::onAvatarDownloaded()
     QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
     Q_ASSERT(reply);
 
-    qDebug() << "Avatar recieved for " << m_uid;
     QImage temporary = QImage::fromData(reply->readAll());
 
     if (temporary.width() > 50 || temporary.height() > 50) {
