@@ -1,11 +1,15 @@
 #include <QtGui/QApplication>
 #include <QDebug>
 
+#include "qmaemo5homescreenadaptor.h"
+
 #include "fbsession.h"
 #include "fblogindialog.h"
 
 #include "mainwindow.h"
 #include "facebrick.h"
+#include "newsfeed.h"
+#include "desktopwidget.h"
 
 int main(int argc, char *argv[])
 {
@@ -21,12 +25,23 @@ int main(int argc, char *argv[])
 
     // Initialise us
     FaceBrick::instance(session);
+    NewsFeed::instance();
 
-    MainWindow w(0);
-    w.show();
+    DesktopWidget w;
+
+    if (QCoreApplication::arguments().count() > 1 && QCoreApplication::arguments().at(1) == "main") {
+        MainWindow::instance()->show();
+    }
+    else {
+        QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&w);
+        adaptor->setSettingsAvailable(false);
+
+        w.show();
+    }
 
     int retval = a.exec();
     delete FaceBrick::instance();
+    delete NewsFeed::instance();
     delete session;
     return retval;
 }
