@@ -35,7 +35,8 @@ const int verticalAvatarPadding = 10;
 const int horizontalAvatarPadding = 20;
 
 NewsFeedDelegate::NewsFeedDelegate(QObject *parent)
-    : QStyledItemDelegate(parent)
+    : QStyledItemDelegate(parent),
+    m_fontSizeDifference(0)
 {
     m_postTextCache.setMaxCost(5);
     m_postTimeCache.setMaxCost(10);
@@ -207,7 +208,7 @@ QTextLayout *NewsFeedDelegate::getNameTextLayout(const QString &text, const QSty
     QFont font = option.font;
     font.setBold(true);
 
-    font.setPointSize(option.font.pointSize() + fontSizeDifference() - 1);
+    font.setPointSize(option.font.pointSize() + fontSizeDifference() + m_fontSizeDifference - 1);
     layout->setFont(font);
     layoutText(layout, option.rect, (avatarWidth + horizontalAvatarPadding));
 
@@ -229,7 +230,7 @@ QTextLayout *NewsFeedDelegate::getStoryTextLayout(const QString &text, const QSt
     layout = new QTextLayout(mangledText);
 
     QFont font = option.font;
-    font.setPointSize(option.font.pointSize() + fontSizeDifference() - 1);
+    font.setPointSize(option.font.pointSize() + fontSizeDifference() + m_fontSizeDifference - 1);
     layout->setFont(font);
     layoutText(layout, option.rect, (avatarWidth + horizontalAvatarPadding));
 
@@ -249,7 +250,7 @@ QTextLayout *NewsFeedDelegate::getTimeTextLayout(const QString &text, const QSty
     layout = new QTextLayout(text);
 
     QFont font = option.font;
-    font.setPointSize(option.font.pointSize() + fontSizeDifference());
+    font.setPointSize(option.font.pointSize() + fontSizeDifference() + m_fontSizeDifference);
 
     QTextOption opt = layout->textOption();
     opt.setAlignment(Qt::AlignRight | Qt::AlignTop);
@@ -292,7 +293,7 @@ QTextLayout *NewsFeedDelegate::getAttachmentDescriptionTextLayout(const QString
     layout = new QTextLayout(mangledText);
 
     QFont font = option.font;
-    font.setPointSize(option.font.pointSize() + fontSizeDifference() - 1);
+    font.setPointSize(option.font.pointSize() + fontSizeDifference() + m_fontSizeDifference - 1);
     layout->setFont(font);
     layoutText(layout, option.rect, ((avatarWidth * 2) + horizontalAvatarPadding * 2.5));
 
@@ -330,3 +331,10 @@ int NewsFeedDelegate::fontSizeDifference() const
     settings.endGroup();
     return fontSize;
 }
+
+/** This method is used to set a font size difference specific for the widget/window calling it,
+ * as we want the desktop widget to have a smaller font size than the application itself */
+void NewsFeedDelegate::setWidgetFontSize(int fontSize)
+{
+    m_fontSizeDifference = fontSize;
+}
