@@ -15,20 +15,26 @@
  * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <QList>
+
 #include "fbconnectglobal.h"
 
 #include "newsfeedmodel.h"
 #include "newsfeedpost.h"
 #include "facebookaccount.h"
 
+static QList<NewsFeedModel *> listOfModels;
+
 NewsFeedModel::NewsFeedModel(QObject *parent, bool newestAtTop) :
     QAbstractListModel(parent),
     m_newestAtTop(newestAtTop)
 {
+    listOfModels.append(this);
 }
 
 NewsFeedModel::~NewsFeedModel()
 {
+    listOfModels.removeAll(this);
 }
 
 int NewsFeedModel::rowCount(const QModelIndex&) const
@@ -119,3 +125,14 @@ long long NewsFeedModel::newestCreatedTime() const
     else
         return m_posts.at(m_posts.count() - 1)->createdTime();
 }
+
+void NewsFeedModel::fontSizeChanged()
+{
+    emit layoutAboutToBeChanged();
+    emit layoutChanged();
+}
+
+QList<NewsFeedModel *> NewsFeedModel::getNewsFeedModelList()
+{
+    return listOfModels;
+}
